@@ -1,5 +1,6 @@
 import re
 
+import pandas as pd
 
 """
 检索结果的导入
@@ -9,6 +10,36 @@ import re
 """
 
 
+def mq_modpep_to_intseq_1_6(x):
+    x = x.replace('_', '')
+    if '(Acetyl (Protein N-term))' in x:
+        x = x.replace('(Acetyl (Protein N-term))', '')
+        x = '*' + x
+    else:
+        x = '@' + x
+    x = x.replace('C(Carbamidomethyl (C))', 'C')
+    x = x.replace('M(Oxidation (M))', '1')
+    x = x.replace('S(Phospho (STY))', '2')
+    x = x.replace('T(Phospho (STY))', '3')
+    x = x.replace('Y(Phospho (STY))', '4')
+    return x
+
+
+def mq_modpep_to_intseq_1_5(x):
+    x = x.replace('_', '')
+    if '(ac)' in x:
+        x = x.replace('(ac)', '')
+        x = '*' + x
+    else:
+        x = '@' + x
+    x = x.replace('C(Carbamidomethyl (C))', 'C')
+    x = x.replace('M(ox)', '1')
+    x = x.replace('S(ph)', '2')
+    x = x.replace('T(ph)', '3')
+    x = x.replace('Y(ph)', '4')
+    return x
+
+
 def ion_info_from_mq(need_ion_type=('b', 'y'), verify_mass=True, verify_tolerance=20):
     pass
 
@@ -55,7 +86,7 @@ def inten_from_mq(x):
                 frag += f'-{ex_mod},H3PO4'
 
             else:
-                frag += f'-noloss'
+                frag += f'-Noloss'
 
             current_num = ion_num
 
@@ -64,11 +95,20 @@ def inten_from_mq(x):
     return inten_dict
 
 
-def show_ion_pair(result_df, iloc):
-    for _ in zip(result_df.iloc[iloc]['Masses'].split(';'),
-                 result_df.iloc[iloc]['Matches'].split(';'),
-                 result_df.iloc[iloc]['Intensities'].split(';')):
-        print(_)
-    # pd.DataFrame(zip(jeff_mq_site_filter_df.loc[0]['Masses'].split(';'),
-    # jeff_mq_site_filter_df.loc[0]['Matches'].split(';'),
-    # jeff_mq_site_filter_df.loc[0]['Intensities'].split(';')))
+def show_ion_pair(result_df, iloc, return_df=True):
+    ion_pairs = list(zip(result_df.iloc[iloc]['Masses'].split(';'),
+                         result_df.iloc[iloc]['Matches'].split(';'),
+                         result_df.iloc[iloc]['Intensities'].split(';')))
+    if return_df:
+        return pd.DataFrame(ion_pairs, columns=['FragMz', 'Frag', 'Inten'])
+    else:
+        for _ in ion_pairs:
+            print(_)
+
+
+def remove_reverse_hits(evi_msms: pd.DataFrame):
+    return evi_msms.loc[evi_msms['Reverse'] != '+']
+
+
+def remove_zero_inten_hits(evi_msms: pd.DataFrame):
+    return evi_msms.loc[evi_msms['Intensity'] > 0]
